==> coq-7.0.tar.gz: coq-7.0/tactics/tacentries.mli <==
(***********************************************************************)
(*  v      *   The Coq Proof Assistant  /  The Coq Development Team    *)
(* <O___,, *        INRIA-Rocquencourt  &  LRI-CNRS-Orsay              *)
(*   \VV/  *************************************************************)
(*    //   *      This file is distributed under the terms of the      *)
(*         *       GNU Lesser General Public License Version 2.1       *)
(***********************************************************************)

(*i $Id: tacentries.mli,v 1.7 2001/03/15 13:38:43 filliatr Exp $ i*)

(*i*)
open Proof_type
open Tacmach
(*i*)

(* Registered tactics. *)

val v_absurd        : tactic_arg list -> tactic
val v_contradiction : tactic_arg list -> tactic
val v_reflexivity   : tactic_arg list -> tactic
val v_symmetry      : tactic_arg list -> tactic
val v_transitivity  : tactic_arg list -> tactic
val v_intro         : tactic_arg list -> tactic
val v_introsUntil   : tactic_arg list -> tactic
(*i val v_tclIDTAC      : tactic_arg list -> tactic i*)
val v_assumption    : tactic_arg list -> tactic
val v_exact         : tactic_arg list -> tactic
val v_reduce        : tactic_arg list -> tactic
val v_constructor   : tactic_arg list -> tactic
val v_left          : tactic_arg list -> tactic
val v_right         : tactic_arg list -> tactic
val v_split         : tactic_arg list -> tactic
val v_clear         : tactic_arg list -> tactic
val v_move          : tactic_arg list -> tactic
val v_move_dep      : tactic_arg list -> tactic
val v_apply         : tactic_arg list -> tactic
val v_cutAndResolve : tactic_arg list -> tactic
val v_cut           : tactic_arg list -> tactic
val v_lettac        : tactic_arg list -> tactic
val v_generalize    : tactic_arg list -> tactic
val v_generalize_dep : tactic_arg list -> tactic
val v_specialize    : tactic_arg list -> tactic
val v_elim          : tactic_arg list -> tactic
val v_elimType      : tactic_arg list -> tactic
val v_induction     : tactic_arg list -> tactic
val v_case          : tactic_arg list -> tactic
val v_caseType      : tactic_arg list -> tactic
val v_destruct      : tactic_arg list -> tactic
val v_fix           : tactic_arg list -> tactic
val v_cofix         : tactic_arg list -> tactic

==> coq_7.2.orig.tar.gz: coq-7.2.orig/tactics/tacentries.mli <==
(***********************************************************************)
(*  v      *   The Coq Proof Assistant  /  The Coq Development Team    *)
(* <O___,, *        INRIA-Rocquencourt  &  LRI-CNRS-Orsay              *)
(*   \VV/  *************************************************************)
(*    //   *      This file is distributed under the terms of the      *)
(*         *       GNU Lesser General Public License Version 2.1       *)
(***********************************************************************)

(*i $Id: tacentries.mli,v 1.12 2001/11/19 15:44:29 clrenard Exp $ i*)

(*i*)
open Proof_type
open Tacmach
(*i*)

(* Registered tactics. *)

val v_absurd        : tactic_arg list -> tactic
val v_contradiction : tactic_arg list -> tactic
val v_reflexivity   : tactic_arg list -> tactic
val v_symmetry      : tactic_arg list -> tactic
val v_transitivity  : tactic_arg list -> tactic
val v_intro         : tactic_arg list -> tactic
val v_introsUntil   : tactic_arg list -> tactic
(*i val v_tclIDTAC      : tactic_arg list -> tactic i*)
val v_assumption    : tactic_arg list -> tactic
val v_exact         : tactic_arg list -> tactic
val v_reduce        : tactic_arg list -> tactic
val v_constructor   : tactic_arg list -> tactic
val v_left          : tactic_arg list -> tactic
val v_right         : tactic_arg list -> tactic
val v_split         : tactic_arg list -> tactic
val v_clear         : tactic_arg list -> tactic
val v_clear_body    : tactic_arg list -> tactic
val v_move          : tactic_arg list -> tactic
val v_move_dep      : tactic_arg list -> tactic
val v_apply         : tactic_arg list -> tactic
val v_cutAndResolve : tactic_arg list -> tactic
val v_cut           : tactic_arg list -> tactic
val v_truecut       : tactic_arg list -> tactic
val v_lettac        : tactic_arg list -> tactic
val v_generalize    : tactic_arg list -> tactic
val v_generalize_dep : tactic_arg list -> tactic
val v_specialize    : tactic_arg list -> tactic
val v_elim          : tactic_arg list -> tactic
val v_elimType      : tactic_arg list -> tactic
val v_induction     : tactic_arg list -> tactic
(*i val v_new_induction : tactic_arg list -> tactic i*)
val v_case          : tactic_arg list -> tactic
val v_caseType      : tactic_arg list -> tactic
val v_destruct      : tactic_arg list -> tactic
(*i val v_new_destruct  : tactic_arg list -> tactic i*)
val v_fix           : tactic_arg list -> tactic
val v_cofix         : tactic_arg list -> tactic
val vernac_instantiate : tactic_arg list -> tactic
